@@ -20,6 +20,9 @@ Features:
     - Request timers and another info
     - Certificate validation
     - ipv6 support
+    - Basic/Digest authentication
+    - OAuth support!
+    - Debug request and response headers
 
 :copyright: (c) 2011 by Alexandr Lispython (alex@obout.ru).
 :license: BSD, see LICENSE for more details.
@@ -29,7 +32,7 @@ __all__ = ('get', 'put', 'head', 'post', 'delete', 'request', 'options',
            'Request', 'Response', 'get_version')
 __author__ = "Alex Lispython (alex@obout.ru)"
 __license__ = "BSD, see LICENSE for more details"
-__version_info__ = (0, 0, 2)
+__version_info__ = (0, 0, 3)
 __version__ = ".".join(map(str, __version_info__))
 __maintainer__ = "Alexandr Lispython (alex@obout.ru)"
 
@@ -39,4 +42,4 @@ def get_version():
 
 from .methods import get, put, head, post, delete, request, options
 from .core import Request, Response
-from .exceptions import CurlError, InterfaceError, InvalidMethod
+from .exceptions import CurlError, InterfaceError, InvalidMethod, AuthError
