@@ -135,8 +135,9 @@ class Request(object):
 
     def __init__(self, method, url, params=None, data=None, headers=None, cookies=None,
                  files=None, timeout=None, connection_timeout=None, allow_redirects=False,
-                 max_redirects=5, proxies=None, auth=None, network_interface=None, use_gzip=None,
-                 validate_cert=False, ca_certs=None, cert=None, debug=False, user_agent=None, ip_v6=False, **kwargs):
+                 max_redirects=5, proxy=None, auth=None, network_interface=None, use_gzip=None,
+                 validate_cert=False, ca_certs=None, cert=None, debug=False, user_agent=None,
+                 ip_v6=False, options=None, **kwargs):
         """A single HTTP / HTTPS request
 
         Arguments:
@@ -155,7 +156,7 @@ class Request(object):
         - `timeout`: (float) connection time out
         - `connection_timeout`: (float)
         - `allow_redirects`: (bool) follow redirects parametr
-        - `proxies`: (dict, tuple or list) of proxies
+        - `proxy`: (dict, tuple or list) of proxies
            Examples:
                ('http', ('127.0.0.1', 9050))
                ('http', ('127.0.0.1', 9050, ('username', 'password'))
@@ -173,6 +174,7 @@ class Request(object):
         - `debug`: (bool) use for `pycurl.DEBUGFUNCTION`
         - `user_agent`: (string) user agent
         - `ip_v6`: (bool) use ipv6 protocol
+        - `options`: (tuple, list) low level pycurl options using
         """
         self._url = url
         if not method or not isinstance(method, StringTypes):
@@ -207,7 +209,13 @@ class Request(object):
         else:
             self._cookies = None
 
-        self._proxies = data_wrapper(proxies)
+        if isinstance(proxy, NoneType):
+            self._proxy = proxy
+        elif isinstance(proxy, TupleType):
+            if len(proxy) != 2 or not isinstance(proxy[1], TupleType):
+                raise InterfaceError('Proxy must be a tuple object')
+            else:
+                self._proxy = proxy
 
         if not isinstance(network_interface, (StringTypes, NoneType)):
             raise InterfaceError("Network interface argument must be string or None")
@@ -242,6 +250,13 @@ class Request(object):
 
         self.response = None
 
+        if options is None:
+            self._options = None
+        elif isinstance(options, (ListType, TupleType)):
+            self._options = data_wrapper(options)
+        else:
+            raise InterfaceError("options must be None, ListType or TupleType")
+
     def __repr__(self, ):
         # TODO: collect `Request` settings into representation string
         return "<%s: %s [ %s ]>" % (self.__class__.__name__, self._method, self._url)
@@ -295,10 +310,9 @@ class Request(object):
         Returns:
         - `response` - :Response instance
         """
-        self._url = self._build_url()
 
         try:
-            opener, body_output, headers_output = self.build_opener(self._url)
+            opener, body_output, headers_output = self.build_opener(self._build_url())
             opener.perform()
             # if close before getinfo, raises pycurl.error can't invote getinfo()
             # opener.close()
@@ -341,6 +355,12 @@ class Request(object):
         opener.setopt(pycurl.HEADERFUNCTION, headers_output.write)
         opener.setopt(pycurl.WRITEFUNCTION, body_output.write)
 
+        if isinstance(self._auth, AuthManager):
+            self._auth.setup_request(self)
+            self._auth.setup(opener)
+        else:
+            opener.unsetopt(pycurl.USERPWD)
+
         if self._headers:
             logger.debug("Setup custom headers %s" %
                          "\r\n".join(["%s: %s" % (f, v) for f, v
@@ -385,12 +405,13 @@ class Request(object):
             opener.setopt(pycurl.INTERFACE, self._network_interface)
 
         # Setup proxy for request
-        if self._proxies is not None:
-            logger.debug("Use proxies %s" % self._proxies)
-            if len(self._proxies) > 2:
-                proxy_type, proxy_addr, proxy_auth = self._proxies
+        if self._proxy is not None:
+            logger.debug("Use proxies %s - %s" % self._proxy)
+            if len(self._proxy) > 2:
+                proxy_type, proxy_addr, proxy_auth = self._proxy
             else:
-                proxy_type, proxy_addr, proxy_auth = self._proxies, None
+                proxy_type, proxy_addr = self._proxy
+                proxy_auth = None
 
             opener.setopt(pycurl.PROXY, proxy_addr[0])
             opener.setopt(pycurl.PROXYPORT, proxy_addr[1])
@@ -510,10 +531,9 @@ class Request(object):
                     # use postfields to send vars as application/x-www-form-urlencoded
                     # opener.setopt(pycurl.POSTFIELDS, encoded_data)
 
-        if isinstance(self._auth, AuthManager):
-            self._auth.setup(opener)
-        else:
-            opener.unsetopt(pycurl.USERPWD)
+        if isinstance(self._options, (TupleType, ListType)):
+            for key, value in self._options:
+                opener.setopt(key, value)
 
         return opener, body_output, headers_output
 
@@ -656,7 +676,8 @@ class Response(object):
                 if not header:
                     continue
                 elif not header.startswith("HTTP"):
-                    field, value = header.split(": ")
+                    print(header)
+                    field, value = header.split(":", 1)
                     if field.startswith("Location"):
                         # maybe not good
                         if not value.startswith("http"):
